#line 1 "ifs_lex.c"

#line 3 "ifs_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer ifs_yy_create_buffer
#define yy_delete_buffer ifs_yy_delete_buffer
#define yy_scan_buffer ifs_yy_scan_buffer
#define yy_scan_string ifs_yy_scan_string
#define yy_scan_bytes ifs_yy_scan_bytes
#define yy_init_buffer ifs_yy_init_buffer
#define yy_flush_buffer ifs_yy_flush_buffer
#define yy_load_buffer_state ifs_yy_load_buffer_state
#define yy_switch_to_buffer ifs_yy_switch_to_buffer
#define yypush_buffer_state ifs_yypush_buffer_state
#define yypop_buffer_state ifs_yypop_buffer_state
#define yyensure_buffer_stack ifs_yyensure_buffer_stack
#define yy_flex_debug ifs_yy_flex_debug
#define yyin ifs_yyin
#define yyleng ifs_yyleng
#define yylex ifs_yylex
#define yylineno ifs_yylineno
#define yyout ifs_yyout
#define yyrestart ifs_yyrestart
#define yytext ifs_yytext
#define yywrap ifs_yywrap
#define yyalloc ifs_yyalloc
#define yyrealloc ifs_yyrealloc
#define yyfree ifs_yyfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

#ifdef yy_create_buffer
#define ifs_yy_create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer ifs_yy_create_buffer
#endif

#ifdef yy_delete_buffer
#define ifs_yy_delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer ifs_yy_delete_buffer
#endif

#ifdef yy_scan_buffer
#define ifs_yy_scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer ifs_yy_scan_buffer
#endif

#ifdef yy_scan_string
#define ifs_yy_scan_string_ALREADY_DEFINED
#else
#define yy_scan_string ifs_yy_scan_string
#endif

#ifdef yy_scan_bytes
#define ifs_yy_scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes ifs_yy_scan_bytes
#endif

#ifdef yy_init_buffer
#define ifs_yy_init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer ifs_yy_init_buffer
#endif

#ifdef yy_flush_buffer
#define ifs_yy_flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer ifs_yy_flush_buffer
#endif

#ifdef yy_load_buffer_state
#define ifs_yy_load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state ifs_yy_load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define ifs_yy_switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer ifs_yy_switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define ifs_yypush_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state ifs_yypush_buffer_state
#endif

#ifdef yypop_buffer_state
#define ifs_yypop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state ifs_yypop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define ifs_yyensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack ifs_yyensure_buffer_stack
#endif

#ifdef yylex
#define ifs_yylex_ALREADY_DEFINED
#else
#define yylex ifs_yylex
#endif

#ifdef yyrestart
#define ifs_yyrestart_ALREADY_DEFINED
#else
#define yyrestart ifs_yyrestart
#endif

#ifdef yylex_init
#define ifs_yylex_init_ALREADY_DEFINED
#else
#define yylex_init ifs_yylex_init
#endif

#ifdef yylex_init_extra
#define ifs_yylex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra ifs_yylex_init_extra
#endif

#ifdef yylex_destroy
#define ifs_yylex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy ifs_yylex_destroy
#endif

#ifdef yyget_debug
#define ifs_yyget_debug_ALREADY_DEFINED
#else
#define yyget_debug ifs_yyget_debug
#endif

#ifdef yyset_debug
#define ifs_yyset_debug_ALREADY_DEFINED
#else
#define yyset_debug ifs_yyset_debug
#endif

#ifdef yyget_extra
#define ifs_yyget_extra_ALREADY_DEFINED
#else
#define yyget_extra ifs_yyget_extra
#endif

#ifdef yyset_extra
#define ifs_yyset_extra_ALREADY_DEFINED
#else
#define yyset_extra ifs_yyset_extra
#endif

#ifdef yyget_in
#define ifs_yyget_in_ALREADY_DEFINED
#else
#define yyget_in ifs_yyget_in
#endif

#ifdef yyset_in
#define ifs_yyset_in_ALREADY_DEFINED
#else
#define yyset_in ifs_yyset_in
#endif

#ifdef yyget_out
#define ifs_yyget_out_ALREADY_DEFINED
#else
#define yyget_out ifs_yyget_out
#endif

#ifdef yyset_out
#define ifs_yyset_out_ALREADY_DEFINED
#else
#define yyset_out ifs_yyset_out
#endif

#ifdef yyget_leng
#define ifs_yyget_leng_ALREADY_DEFINED
#else
#define yyget_leng ifs_yyget_leng
#endif

#ifdef yyget_text
#define ifs_yyget_text_ALREADY_DEFINED
#else
#define yyget_text ifs_yyget_text
#endif

#ifdef yyget_lineno
#define ifs_yyget_lineno_ALREADY_DEFINED
#else
#define yyget_lineno ifs_yyget_lineno
#endif

#ifdef yyset_lineno
#define ifs_yyset_lineno_ALREADY_DEFINED
#else
#define yyset_lineno ifs_yyset_lineno
#endif

#ifdef yywrap
#define ifs_yywrap_ALREADY_DEFINED
#else
#define yywrap ifs_yywrap
#endif

#ifdef yyalloc
#define ifs_yyalloc_ALREADY_DEFINED
#else
#define yyalloc ifs_yyalloc
#endif

#ifdef yyrealloc
#define ifs_yyrealloc_ALREADY_DEFINED
#else
#define yyrealloc ifs_yyrealloc
#endif

#ifdef yyfree
#define ifs_yyfree_ALREADY_DEFINED
#else
#define yyfree ifs_yyfree
#endif

#ifdef yytext
#define ifs_yytext_ALREADY_DEFINED
#else
#define yytext ifs_yytext
#endif

#ifdef yyleng
#define ifs_yyleng_ALREADY_DEFINED
#else
#define yyleng ifs_yyleng
#endif

#ifdef yyin
#define ifs_yyin_ALREADY_DEFINED
#else
#define yyin ifs_yyin
#endif

#ifdef yyout
#define ifs_yyout_ALREADY_DEFINED
#else
#define yyout ifs_yyout
#endif

#ifdef yy_flex_debug
#define ifs_yy_flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug ifs_yy_flex_debug
#endif

#ifdef yylineno
#define ifs_yylineno_ALREADY_DEFINED
#else
#define yylineno ifs_yylineno
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE yylex.
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define ifs_yywrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 64
#define YY_END_OF_BUFFER 65
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[344] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        2,    2,    7,    7,   65,   62,   63,    6,   62,   55,
       56,   62,   62,   58,   51,   52,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   53,   54,   57,
       57,   41,   37,   39,   35,   32,   57,   57,   57,   57,
       57,   57,   57,   57,    2,    4,    3,    7,    8,    0,
       58,   60,    1,   59,    0,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   29,   57,   38,   40,   36,   33,   57,   42,
       57,   57,   57,   57,   57,   57,   57,    2,    3,    3,

        5,    7,    0,   59,    0,    0,   61,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   28,   57,   57,   43,   57,   57,   46,
       57,   57,   57,    0,   60,    0,    0,   59,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   30,   57,   34,   57,   57,   57,   57,   45,
       57,    0,   59,   57,   57,   57,   57,   57,   57,   31,
       57,   57,   57,   57,   57,   57,   57,   57,   44,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,

       57,   49,   57,   57,   57,   57,   57,   57,    0,   22,
       57,   57,   57,   57,   57,   57,   57,    0,   10,   57,
       47,   48,   50,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,    0,   15,   57,   57,   57,    0,
       19,   57,   57,   57,    0,   13,   57,   57,   57,   57,
       57,   57,   57,   57,   57,    0,   23,   57,   57,   57,
        0,   14,   57,   57,   57,   57,   57,   57,   57,    0,
       18,   57,   57,   57,   57,   57,   57,   57,   57,   57,

        0,   16,   57,    0,   24,   57,   57,   57,   57,   57,
       57,    0,    9,   57,    0,   17,   57,   57,   57,   57,
       57,    0,   11,   57,    0,   25,   57,   57,   57,   57,
        0,   12,    0,   26,   57,    0,   20,   57,    0,   27,
        0,   21,    0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    9,   10,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   12,    1,   13,
        1,   14,    1,    1,   15,   16,   17,   18,   19,   20,
       21,   22,   23,   24,   24,   25,   26,   27,   28,   29,
       24,   30,   31,   32,   33,   34,   35,   36,   37,   24,
       38,    1,   39,    1,   40,    1,   41,   42,   43,   44,

       45,   46,   47,   48,   49,   24,   24,   50,   51,   52,
       53,   54,   24,   55,   56,   57,   58,   59,   60,   61,
       62,   24,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[63] =
    {   0,
        1,    1,    2,    3,    4,    1,    1,    1,    1,    1,
        5,    1,    1,    1,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    1,    1,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5
    } ;

static const flex_int16_t yy_base[351] =
    {   0,
        0,    0,   36,   37,   82,  124,   42,   43,  168,  209,
       64,   72,  796,  773,  764, 1047, 1047, 1047,   67, 1047,
       70,  751,  742,   74, 1047, 1047,   57,  683,   61,   91,
       79,   86,  122,   97,  132,  104,  133, 1047, 1047,  154,
      143,  226,   69,  149,  159,  202,  163,  142,  128,  190,
      181,  216,  183,  224,    0, 1047,  112,    0, 1047,  681,
      251,  223, 1047,  255,  198,    0,  675,  248,  265,  250,
      266,  225,  268,  273,  276,  278,  261,  279,  100,  290,
      277,  297,  551,  295,  550,  545,  505,  454,  302,  293,
      304,  309,  312,  318,  319,  330,  337,    0,  209,  334,

     1047,    0,  347,  314,  358,  395,  394,  345,  321,  361,
      366,  369,  346,  359,  371,  374,  372,  373,  376,  378,
      385,  390,  392,  349,  399,  393,  336,  388,  389,  308,
      400,  405,  417,  284,  283,  423,  281,  272,  116,  412,
      117,  421,  426,  430,  425,  435,  434,  437,  442,  446,
      450,  448,  239,  447,  237,  451,  461,  465,  452,  205,
      467,  194,  185,  477,  474,  471,  476,  487,  488,  168,
      493,  491,  496,  494,  503,  449,  501,  510,  155,  516,
      514,  523,  530,  532,  521,  527,  535,  518,  547,  571,
      560,  541,  552,  570,  575,  543,  568,  595,  576,  569,

      582,  137,  577,  591,  584,  589,  588,  593,  620, 1047,
      599,  608,  607,  613,  620,  614,  616,  641, 1047,  638,
      113,  110,  107,  636,  623,  637,  649,  646,  644,  648,
      650,  654,  655,  652,  661,  674,  659,  677,  680,  708,
      679,  686,  693,  722,  707,  688,  702,  726,  711,  724,
      706,  720,  729,  733,  747, 1047,  734,  740,  743,  764,
     1047,  769,  749,  764,  790, 1047,  795,  774,  744,  776,
      763,  778,  790,  746,  808,  810, 1047,  807,  812,  818,
      829, 1047,  775,  815,  825,  806,  823,  837,  833,  843,
     1047,  854,  847,  852,  843,  860,  865,  866,  879,  863,

      881, 1047,  897,  884, 1047,  891,  892,  877,  893,  896,
      913,  918, 1047,  894,  925, 1047,  929,  915,  922,  924,
      934,  944, 1047,  950,  952, 1047,  955,  952,  974,  959,
      977, 1047,  979, 1047,  990,  993, 1047,  996, 1007, 1047,
     1009, 1047, 1047, 1021, 1026,   81, 1031, 1036, 1041,   79
    } ;

static const flex_int16_t yy_def[351] =
    {   0,
      343,    1,    1,    1,    1,    1,    1,    1,    1,    1,
      344,  344,  345,  345,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  343,  343,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  347,  343,  348,  349,  343,  343,
      343,  343,  343,  343,  343,  350,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  347,  348,  348,

      343,  349,  343,  343,  343,  343,  343,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  343,  343,  343,  343,  343,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  343,  343,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,

      346,  346,  346,  346,  346,  346,  346,  346,  343,  343,
      346,  346,  346,  346,  346,  346,  346,  343,  343,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  346,  346,  346,  346,  346,
      346,  346,  346,  346,  343,  343,  346,  346,  346,  343,
      343,  346,  346,  346,  343,  343,  346,  346,  346,  346,
      346,  346,  346,  346,  346,  343,  343,  346,  346,  346,
      343,  343,  346,  346,  346,  346,  346,  346,  346,  343,
      343,  346,  346,  346,  346,  346,  346,  346,  346,  346,

      343,  343,  346,  343,  343,  346,  346,  346,  346,  346,
      346,  343,  343,  346,  343,  343,  346,  346,  346,  346,
      346,  343,  343,  346,  343,  343,  346,  346,  346,  346,
      343,  343,  343,  343,  346,  343,  343,  346,  343,  343,
      343,  343,    0,  343,  343,  343,  343,  343,  343,  343
    } ;

static const flex_int16_t yy_nxt[1110] =
    {   0,
       16,   16,   17,   18,   16,   19,   20,   21,   22,   23,
       24,   16,   25,   26,   27,   28,   29,   30,   28,   31,
       28,   28,   28,   28,   32,   28,   33,   28,   34,   28,
       35,   36,   28,   37,   28,   28,   28,   38,   39,   28,
       27,   28,   29,   30,   28,   31,   28,   28,   28,   32,
       28,   33,   28,   34,   28,   35,   36,   28,   37,   28,
       28,   28,   40,   40,   47,   47,   56,   66,   57,   48,
       48,   66,   41,   41,   56,   60,   57,   61,   60,   66,
       61,   68,   64,   66,   61,   67,   85,   40,   40,   66,
       47,   47,   65,   73,   48,   48,   66,   41,   41,   42,

       69,   66,   43,   44,   45,   70,   68,   66,   74,   71,
       66,   77,   85,   72,   66,   46,  100,   66,   65,   73,
       66,  101,  120,   66,   78,   42,   66,   66,   43,   44,
       45,   70,   66,   81,   74,   71,   75,   77,   66,   72,
       46,   42,   66,   66,   43,   44,   45,   66,  120,   78,
      164,   82,   66,   66,   76,   92,  166,   46,   81,   66,
       79,   84,   75,   80,   66,   66,   86,   42,   75,   66,
       43,   44,   45,   66,   91,  164,   87,   82,   66,   76,
       92,   83,   46,   49,   50,   79,   76,   84,   80,   90,
       51,   66,   86,   66,   75,  163,   52,   53,   54,   91,

       66,   96,   87,  106,  163,  106,   83,   94,  107,   49,
       50,   76,   66,  343,   90,   66,   51,   93,  343,   88,
       82,   52,   53,   54,   49,   50,   66,   96,   89,   69,
       77,   51,   94,   62,   66,   66,   66,   52,   53,   54,
       70,  103,   93,   95,   71,   88,   82,   66,   72,   66,
       49,   50,   79,   89,  113,   97,   77,   51,   66,   64,
       66,   61,   52,   53,   54,  104,   70,  103,   95,   65,
       71,   66,  108,  105,   72,   66,   66,   79,   66,  113,
       97,  110,  138,   66,  109,  111,   66,   66,   66,   66,
      118,  138,  114,  135,  135,   65,  112,  108,  115,  105,

       66,  116,  117,   66,  121,   66,  110,   66,  119,  122,
      109,  111,   66,  123,   66,  118,  125,  114,   66,   66,
      126,  112,   66,  115,  104,  124,  116,  117,   66,   66,
      121,   66,  136,  119,  122,  127,  128,  129,  100,  123,
       66,  131,  125,  101,  132,  126,   66,   66,  119,  130,
      124,  121,  134,  140,  134,   66,   66,  135,  136,   66,
      127,  128,  129,  137,  144,  137,  133,  131,  138,   66,
      132,   66,  139,  119,  130,  141,   66,  121,  140,   66,
      142,   66,   66,   66,   66,  143,   66,  149,   66,  145,
      144,  133,  147,  146,  151,   66,  148,  139,   66,   66,

       66,  141,   66,   66,  107,  107,  142,  150,  153,   66,
       66,  143,  157,  149,  145,   66,  152,  158,  147,  146,
      151,  148,   66,  154,  155,  156,  159,   66,  162,  160,
      162,   66,  150,  163,  153,   66,   66,  157,  165,  161,
       66,  152,  158,  170,   66,   66,  169,   66,  154,  155,
      156,  159,   66,  167,  160,  168,   66,   66,   66,   66,
       66,   66,   66,  165,   66,  161,  171,  174,  176,  170,
      177,   66,  169,  172,  178,   66,  173,   66,  167,  180,
      168,   66,  179,  182,   66,  175,   66,   66,  196,  181,
      185,  171,  174,  183,  176,  184,  177,   66,   66,  178,

      187,   66,  186,   66,   66,  180,   66,  179,  182,  188,
      192,   66,  193,   66,  181,   66,  185,  197,  183,  189,
       66,  184,  191,  190,   66,  187,   66,  186,   66,  194,
      199,   66,  200,   66,  195,  188,  192,   66,  193,  198,
       66,  201,   66,  197,  189,   66,  207,  191,  190,  203,
      202,   66,  204,   66,  194,   66,  199,   66,  200,  195,
       66,   66,   66,  205,  198,  212,  206,  201,  216,  208,
       66,  207,  209,  209,  211,  203,  202,  204,   66,   66,
       66,   66,  210,  213,  214,   66,   66,   66,  205,  215,
      212,  206,   66,  216,   66,  208,  218,  218,   66,   66,

      211,   66,  221,   66,  222,   66,  219,  217,  213,   66,
      214,  223,  226,  225,  230,  215,  224,   66,   66,  228,
      229,  209,  209,   66,   66,  232,   66,  221,  227,  222,
       66,  210,  231,   66,  220,  234,  223,  226,  233,  225,
      230,  235,  218,  218,  228,  229,   66,   66,   66,  236,
      239,  232,  219,  237,   66,  240,   66,  231,   66,   66,
       66,  234,   66,  233,   66,   66,  235,  238,  243,   66,
      244,   66,  245,  248,  236,  239,  249,  246,  250,  237,
      241,  240,  242,  247,   66,   66,  252,   66,  251,   66,
       66,   62,  238,   66,  243,  244,   66,  245,   66,  248,

      258,  249,  246,   66,  250,  241,  254,  242,  247,  255,
      255,  252,   66,  253,  251,  257,   66,   66,   66,  256,
      259,   66,  263,  260,  260,  262,  258,  265,  265,  267,
       66,  254,   66,  261,   66,  269,   66,  266,  253,   66,
      257,  264,  268,   66,   66,  259,   63,  263,  255,  255,
       66,  262,  270,   66,   66,  267,   66,  271,  256,   66,
      269,   62,  273,  343,  274,  260,  260,  278,  268,  275,
      276,  276,  272,   66,   66,  261,   59,  270,  289,   66,
      277,  286,  271,  284,   66,   66,   66,  273,   66,  274,
      279,  265,  265,  278,  275,  280,  281,  281,  283,   59,

       66,  266,  285,  289,  287,   66,  282,  286,  288,  290,
      290,  276,  276,  343,  295,  279,   66,   66,   66,  291,
      280,  277,   66,  283,  292,   66,  293,  285,   66,  287,
      281,  281,  294,   66,  288,   66,  299,  300,  301,  301,
      282,  296,  298,   66,  290,  290,  297,   66,  302,  343,
      292,  303,  293,   66,  291,  304,  304,   66,  294,  343,
      343,  299,   66,  300,   66,  305,  296,  307,  298,  308,
       66,  297,  306,   66,  309,   66,   66,  303,  343,  310,
      312,  312,  301,  301,  343,  304,  304,   66,  314,   66,
      313,  319,  302,  307,  308,  305,  311,  306,  315,  315,

      309,   66,   66,   66,   66,  310,   66,   66,  316,  317,
      343,  321,  324,  314,  322,  322,  318,  319,  320,  312,
      312,  311,  343,   66,  323,   66,  315,  315,  343,  313,
      325,  325,   66,  327,   66,  317,  316,  321,  324,   66,
      326,  318,  329,  320,   66,  322,  322,  328,  343,  343,
      343,  331,  331,  325,  325,  323,  333,  333,  330,  327,
       66,  332,   66,  326,  343,   66,  334,  343,  329,   66,
      335,  343,  328,  343,  343,  336,  336,  338,  331,  331,
      333,  333,  343,  330,   66,  337,  343,  343,  332,  343,
      334,  339,  339,  343,  336,  336,  335,  341,  341,  343,

       66,  340,  343,  338,  337,  343,   66,  342,  339,  339,
      341,  341,  343,  343,  343,  343,  343,  343,  340,  343,
      342,   55,   55,   55,   55,   55,   58,   58,   58,   58,
       58,   98,  343,   98,  343,   98,   99,  343,   99,   99,
       99,  102,  102,  343,  102,  102,   15,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,

      343,  343,  343,  343,  343,  343,  343,  343,  343
    } ;

static const flex_int16_t yy_chk[1110] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,    7,    8,   11,   27,   11,    7,
        8,   29,    3,    4,   12,   19,   12,   19,   21,   43,
       21,   27,   24,  350,   24,  346,   43,    3,    4,   31,
        7,    8,   24,   31,    7,    8,   32,    3,    4,    5,

       29,   30,    5,    5,    5,   30,   27,   34,   32,   30,
       79,   34,   43,   30,   36,    5,   57,  223,   24,   31,
      222,   57,   79,  221,   34,    5,  139,  141,    5,    5,
        5,   30,   33,   36,   32,   30,   33,   34,   49,   30,
        5,    6,   35,   37,    6,    6,    6,  202,   79,   34,
      139,   37,   48,   41,   33,   49,  141,    6,   36,   44,
       35,   41,   33,   35,   40,  179,   44,    6,   40,   45,
        6,    6,    6,   47,   48,  139,   45,   37,  170,   33,
       49,   40,    6,    9,    9,   35,   40,   41,   35,   47,
        9,   51,   44,   53,   40,  163,    9,    9,    9,   48,

       50,   53,   45,   65,  162,   65,   40,   51,   65,    9,
        9,   40,   46,   99,   47,  160,    9,   50,   99,   46,
       46,    9,    9,    9,   10,   10,   52,   53,   46,   50,
       52,   10,   51,   62,   54,   72,   42,   10,   10,   10,
       42,   62,   50,   52,   42,   46,   46,  155,   42,  153,
       10,   10,   54,   46,   72,   54,   52,   10,   68,   61,
       70,   61,   10,   10,   10,   64,   42,   62,   52,   61,
       42,   77,   68,   64,   42,   69,   71,   54,   73,   72,
       54,   70,  138,   74,   69,   71,   75,   81,   76,   78,
       77,  137,   73,  135,  134,   61,   71,   68,   74,   64,

       80,   75,   76,   90,   80,   84,   70,   82,   78,   81,
       69,   71,   89,   82,   91,   77,   89,   73,  130,   92,
       90,   71,   93,   74,  104,   84,   75,   76,   94,   95,
       80,  109,  104,   78,   81,   91,   92,   93,  100,   82,
       96,   95,   89,  100,   96,   90,  127,   97,   95,   94,
       84,   97,  103,  109,  103,  108,  113,  103,  104,  124,
       91,   92,   93,  105,  113,  105,   97,   95,  105,  114,
       96,  110,  108,   95,   94,  110,  111,   97,  109,  112,
      111,  115,  117,  118,  116,  112,  119,  118,  120,  114,
      113,   97,  116,  115,  120,  121,  117,  108,  128,  129,

      122,  110,  123,  126,  107,  106,  111,  119,  122,  125,
      131,  112,  128,  118,  114,  132,  121,  129,  116,  115,
      120,  117,  140,  123,  125,  126,  131,  133,  136,  132,
      136,  142,  119,  136,  122,  145,  143,  128,  140,  133,
      144,  121,  129,  145,  147,  146,  144,  148,  123,  125,
      126,  131,  149,  142,  132,  143,  150,  154,  152,  176,
      151,  156,  159,  140,   88,  133,  146,  149,  151,  145,
      152,  157,  144,  147,  154,  158,  148,  161,  142,  157,
      143,  166,  156,  159,  165,  150,  167,  164,  176,  158,
      165,  146,  149,  161,  151,  164,  152,  168,  169,  154,

      167,  172,  166,  171,  174,  157,  173,  156,  159,  168,
      173,  177,  174,  175,  158,   87,  165,  177,  161,  169,
      178,  164,  172,  171,  181,  167,  180,  166,  188,  175,
      180,  185,  181,  182,  175,  168,  173,  186,  174,  178,
      183,  182,  184,  177,  169,  187,  188,  172,  171,  184,
      183,  192,  185,  196,  175,   86,  180,  189,  181,  175,
       85,   83,  193,  186,  178,  192,  187,  182,  196,  189,
      191,  188,  190,  190,  191,  184,  183,  185,  197,  200,
      194,  190,  190,  193,  194,  195,  199,  203,  186,  195,
      192,  187,  201,  196,  205,  189,  198,  198,  207,  206,

      191,  204,  199,  208,  200,  198,  198,  197,  193,  211,
      194,  201,  205,  204,  211,  195,  203,  213,  212,  207,
      208,  209,  209,  214,  216,  213,  217,  199,  206,  200,
      215,  209,  212,  225,  198,  215,  201,  205,  214,  204,
      211,  216,  218,  218,  207,  208,  224,  226,  220,  217,
      225,  213,  218,  220,  229,  226,  228,  212,  230,  227,
      231,  215,  234,  214,  232,  233,  216,  224,  228,  237,
      229,  235,  230,  233,  217,  225,  234,  231,  235,  220,
      227,  226,  227,  232,  236,   67,  237,  238,  236,  241,
      239,   60,  224,   28,  228,  229,  242,  230,  246,  233,

      242,  234,  231,  243,  235,  227,  239,  227,  232,  240,
      240,  237,  247,  238,  236,  241,  251,  245,  240,  240,
      243,  249,  246,  244,  244,  245,  242,  248,  248,  249,
      252,  239,  244,  244,  250,  251,  248,  248,  238,  253,
      241,  247,  250,  254,  257,  243,   23,  246,  255,  255,
      258,  245,  252,  259,  269,  249,  274,  253,  255,  263,
      251,   22,  257,   15,  258,  260,  260,  263,  250,  259,
      262,  262,  254,  271,  264,  260,   14,  252,  274,  262,
      262,  271,  253,  269,  268,  283,  270,  257,  272,  258,
      264,  265,  265,  263,  259,  264,  267,  267,  268,   13,

      273,  265,  270,  274,  272,  267,  267,  271,  273,  275,
      275,  276,  276,    0,  283,  264,  286,  278,  275,  275,
      264,  276,  279,  268,  278,  284,  279,  270,  280,  272,
      281,  281,  280,  287,  273,  285,  286,  287,  288,  288,
      281,  284,  285,  289,  290,  290,  284,  288,  288,    0,
      278,  289,  279,  295,  290,  292,  292,  293,  280,    0,
        0,  286,  294,  287,  292,  292,  284,  294,  285,  295,
      296,  284,  293,  300,  296,  297,  298,  289,    0,  297,
      299,  299,  301,  301,    0,  304,  304,  308,  300,  299,
      299,  308,  301,  294,  295,  304,  298,  293,  303,  303,

      296,  306,  307,  309,  314,  297,  310,  303,  303,  306,
        0,  310,  314,  300,  311,  311,  307,  308,  309,  312,
      312,  298,    0,  311,  311,  318,  315,  315,    0,  312,
      317,  317,  319,  318,  320,  306,  315,  310,  314,  317,
      317,  307,  320,  309,  321,  322,  322,  319,    0,    0,
        0,  324,  324,  325,  325,  322,  327,  327,  321,  318,
      324,  324,  328,  325,    0,  327,  327,    0,  320,  330,
      328,    0,  319,    0,    0,  329,  329,  330,  331,  331,
      333,  333,    0,  321,  329,  329,    0,    0,  331,    0,
      333,  335,  335,    0,  336,  336,  328,  338,  338,    0,

      335,  335,    0,  330,  336,    0,  338,  338,  339,  339,
      341,  341,    0,    0,    0,    0,    0,    0,  339,    0,
      341,  344,  344,  344,  344,  344,  345,  345,  345,  345,
      345,  347,    0,  347,    0,  347,  348,    0,  348,  348,
      348,  349,  349,    0,  349,  349,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,
      343,  343,  343,  343,  343,  343,  343,  343,  343,  343,

      343,  343,  343,  343,  343,  343,  343,  343,  343
    } ;

/* Table of booleans, true if rule could match eol. */
static const flex_int32_t yy_rule_can_match_eol[65] =
    {   0,
0, 0, 0, 1, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
    1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 1, 0,     };

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../../../../src/xspice/cmpp/ifs_lex.l"
#define YY_NO_INPUT 1
#line 8 "../../../../src/xspice/cmpp/ifs_lex.l"

/*============================================================================
FILE  ifs_lex.l

MEMBER OF process cmpp

Copyright 1991
Georgia Tech Research Corporation
Atlanta, Georgia 30332
All Rights Reserved

PROJECT A-8503

AUTHORS

    9/12/91  Steve Tynor

MODIFICATIONS

    12/31/91  Bill Kuhn  Change "array" to "vector" and "array_bounds"
                         to "vector_bounds".

SUMMARY

    This file defines tokens applicable to parsing the ifspec.ifs
    file, and actions to be taken on encountering those tokens.

INTERFACES

    None.

REFERENCED FILES

    ifs_yacc.y

NON-STANDARD FEATURES

    None.

============================================================================*/

#include <stdlib.h>

#include "ifs_yacc_y.h"
#include "ifs_yacc.h"

int yyival;
double yydval;

/*
 * IFS specs are case insensitive:
 */

/*---------------------------------------------------------------------------*/

#line 1146 "ifs_lex.c"

#line 1148 "ifs_lex.c"

#define INITIAL 0
#define BOOL 1
#define CTYPE 2
#define DIR 3
#define DTYPE 4
#define comment 5
#define stringl 6

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 78 "../../../../src/xspice/cmpp/ifs_lex.l"


#line 1372 "ifs_lex.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 344 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1047 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			int yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					
    yylineno++;
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 80 "../../../../src/xspice/cmpp/ifs_lex.l"
{ BEGIN(comment); }
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 82 "../../../../src/xspice/cmpp/ifs_lex.l"
/* eat anything that's not a '*' */
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 84 "../../../../src/xspice/cmpp/ifs_lex.l"
/* eat up '*'s not followed by '/'s */
	YY_BREAK
case 4:
/* rule 4 can match eol */
YY_RULE_SETUP
#line 86 "../../../../src/xspice/cmpp/ifs_lex.l"
/* new line */
	YY_BREAK
case YY_STATE_EOF(comment):
#line 88 "../../../../src/xspice/cmpp/ifs_lex.l"
{ifs_yyerror ("Unterminated comment"); 
						BEGIN(INITIAL);
						yyterminate(); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 92 "../../../../src/xspice/cmpp/ifs_lex.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 94 "../../../../src/xspice/cmpp/ifs_lex.l"
{ BEGIN(stringl); }
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 96 "../../../../src/xspice/cmpp/ifs_lex.l"
{ return TOK_STRING_LITERAL; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 98 "../../../../src/xspice/cmpp/ifs_lex.l"
{ BEGIN(INITIAL); }
	YY_BREAK
case YY_STATE_EOF(stringl):
#line 100 "../../../../src/xspice/cmpp/ifs_lex.l"
{ifs_yyerror ("Unterminated string literal");
						BEGIN(INITIAL); 
						yyterminate(); }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 104 "../../../../src/xspice/cmpp/ifs_lex.l"
{BEGIN CTYPE; return TOK_ALLOWED_TYPES;}
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 105 "../../../../src/xspice/cmpp/ifs_lex.l"
{BEGIN BOOL;  return TOK_ARRAY;}
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 106 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_ARRAY_BOUNDS;}
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 107 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_C_FUNCTION_NAME;}
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 108 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_PORT_NAME;}
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 109 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_PORT_TABLE;}
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 110 "../../../../src/xspice/cmpp/ifs_lex.l"
{BEGIN DTYPE; return TOK_DATA_TYPE;}
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 111 "../../../../src/xspice/cmpp/ifs_lex.l"
{BEGIN CTYPE; return TOK_DEFAULT_TYPE;}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 112 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DEFAULT_VALUE;}
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 113 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DESCRIPTION;}
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 114 "../../../../src/xspice/cmpp/ifs_lex.l"
{BEGIN DIR;  return TOK_DIRECTION;}
	YY_BREAK
case 20:
/* rule 20 can match eol */
YY_RULE_SETUP
#line 115 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_STATIC_VAR_NAME;}
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 116 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_STATIC_VAR_TABLE;}
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 117 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_LIMITS;}
	YY_BREAK
case 23:
/* rule 23 can match eol */
YY_RULE_SETUP
#line 118 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_NAME_TABLE;}
	YY_BREAK
case 24:
/* rule 24 can match eol */
YY_RULE_SETUP
#line 119 "../../../../src/xspice/cmpp/ifs_lex.l"
{BEGIN BOOL; return TOK_NULL_ALLOWED;}
	YY_BREAK
case 25:
/* rule 25 can match eol */
YY_RULE_SETUP
#line 120 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_PARAMETER_NAME;}
	YY_BREAK
case 26:
/* rule 26 can match eol */
YY_RULE_SETUP
#line 121 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_PARAMETER_TABLE;}
	YY_BREAK
case 27:
/* rule 27 can match eol */
YY_RULE_SETUP
#line 122 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_SPICE_MODEL_NAME;}
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 124 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_BOOL_YES;}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 125 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_BOOL_NO;}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 126 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_BOOL_YES;}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 127 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_BOOL_NO;}
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 129 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_V;}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 130 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_VD;}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 131 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_VNAM;}
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 132 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_I;}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 133 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_ID;}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 134 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_G;}
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 135 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_GD;}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 136 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_H;}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 137 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_HD;}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 138 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_CTYPE_D;}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 140 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DIR_IN;}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 141 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DIR_OUT;}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 142 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DIR_INOUT;}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 144 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DTYPE_REAL;}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 145 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DTYPE_INT;}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 146 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DTYPE_BOOLEAN;}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 147 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DTYPE_COMPLEX;}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 148 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DTYPE_STRING;}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 149 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DTYPE_POINTER;}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 151 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_LANGLE;}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 152 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_RANGLE;}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 153 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_LBRACKET;}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 154 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_RBRACKET;}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 155 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_COMMA;}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 156 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_DASH;}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 159 "../../../../src/xspice/cmpp/ifs_lex.l"
{return TOK_IDENTIFIER;}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 161 "../../../../src/xspice/cmpp/ifs_lex.l"
{yyival = atoi (yytext);
				 return TOK_INT_LITERAL;}
	YY_BREAK
case 59:
#line 165 "../../../../src/xspice/cmpp/ifs_lex.l"
case 60:
#line 166 "../../../../src/xspice/cmpp/ifs_lex.l"
case 61:
YY_RULE_SETUP
#line 166 "../../../../src/xspice/cmpp/ifs_lex.l"
{yydval = atof (yytext);
				 return TOK_REAL_LITERAL;}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 169 "../../../../src/xspice/cmpp/ifs_lex.l"
; /* ignore anything else */
	YY_BREAK
case 63:
/* rule 63 can match eol */
YY_RULE_SETUP
#line 170 "../../../../src/xspice/cmpp/ifs_lex.l"
; /* ignore anything else */
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 172 "../../../../src/xspice/cmpp/ifs_lex.l"
ECHO;
	YY_BREAK
#line 1789 "ifs_lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(BOOL):
case YY_STATE_EOF(CTYPE):
case YY_STATE_EOF(DIR):
case YY_STATE_EOF(DTYPE):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 344 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 344 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 343);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	if ( c == '\n' )
		
    yylineno++;
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    /* We do not touch yylineno unless the option is enabled. */
    yylineno =  1;
    
    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 172 "../../../../src/xspice/cmpp/ifs_lex.l"


/*--------------------------------------------------------------------------*/

#if 0
void reset_lex_context (void)
{
   BEGIN 0;
}
#endif

